/*
 * Copyright 2009 SpringSource
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.bundlor.blint.support;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import java.util.List;

import org.junit.Test;

import com.springsource.bundlor.blint.support.contributors.BundleManifestVersionValidator;
import com.springsource.bundlor.blint.support.contributors.BundleSymbolicNameValidator;
import com.springsource.bundlor.blint.support.contributors.ExportedNotImportedValidator;
import com.springsource.bundlor.blint.support.contributors.SignedJarFileValidator;
import com.springsource.bundlor.blint.support.contributors.VersionedExportsValidator;
import com.springsource.bundlor.blint.support.contributors.VersionedImportsRangeValidator;
import com.springsource.bundlor.blint.support.contributors.VersionedImportsValidator;

public class DefaultManifestValidatorContributorsFactoryTests {

    @Test
    public void contents() {
        ManifestValidatorContributors contributors = DefaultManifestValidatorContributorsFactory.create();
        assertContainsInstanceOf(contributors.getValidators(), BundleManifestVersionValidator.class, BundleSymbolicNameValidator.class,
            VersionedImportsValidator.class, VersionedExportsValidator.class, ExportedNotImportedValidator.class, SignedJarFileValidator.class,
            VersionedImportsRangeValidator.class);
    }

    private final void assertContainsInstanceOf(List<Validator> validators, Class<?>... clazzes) {
        assertEquals(validators.size(), clazzes.length);
        for (Class<?> clazz : clazzes) {
            for (Validator validator : validators) {
                if (validator.getClass().equals(clazz)) {
                    return;
                }
            }
            fail(String.format("Default contributors does not contain an instance of '%s'", clazz.getName()));
        }
    }
}
